@@ -675,7 +675,12 @@ class NativeSQLSource(SQLAdapterMixIn, AbstractSource):
                         index_name = mo.group(0)
                         elements = index_name.rstrip('_idx').split('_cw_')[1:]
                         etype = elements[0]
-                        rtypes = elements[1:]                        
+                        rtypes = elements[1:]
+                        raise UniqueTogetherError(etype, rtypes)
+                    mo = re.search('columns (.*) are not unique', arg)
+                    if mo is not None: # sqlite in use
+                        rtypes = [c.strip().lstrip('cw_') for c in mo.group(1).split(',')]
+                        etype = '???'
                         raise UniqueTogetherError(etype, rtypes)
             raise
         return cursor
@@ -862,7 +867,6 @@ class NativeSQLSource(SQLAdapterMixIn, AbstractSource):
             cnx.commit()
             return eid
 
-
     def add_info(self, session, entity, source, extid, complete):
         """add type and source info for an eid into the system table"""
         # begin by inserting eid/type/source/extid into the entities table
