@@ -16,9 +16,7 @@
 #
 # You should have received a copy of the GNU Lesser General Public License along
 # with CubicWeb.  If not, see <http://www.gnu.org/licenses/>.
-"""cubicweb-file packaging information
-
-"""
+"""cubicweb-file packaging information"""
 
 distname = "cubicweb-file"
 modname = distname.split('-', 1)[1]
