@@ -369,7 +369,8 @@ class CubicWebPublisher(object):
         """
         path = path or 'view'
         # don't log form values they may contains sensitive information
-        self.info('publish "%s" (form params: %s)', path, req.form.keys())
+        self.info('publish "%s" (%s, form params: %s)',
+                  path, req.session.sessionid, req.form.keys())
         # remove user callbacks on a new request (except for json controllers
         # to avoid callbacks being unregistered before they could be called)
         tstart = clock()
@@ -429,11 +430,12 @@ class CubicWebPublisher(object):
                 self.validation_error_handler(req, ex)
             except (Unauthorized, BadRQLQuery, RequestError), ex:
                 self.error_handler(req, ex, tb=False)
-            except Exception, ex:
+            except BaseException, ex:
                 self.error_handler(req, ex, tb=True)
             except:
                 self.critical('Catch all triggered!!!')
                 self.exception('this is what happened')
+                result = 'oops'
         finally:
             if req.cnx and not commited:
                 try:
